@@ -1489,6 +1489,23 @@ class TestRebuildBaremetalProvisionState(TestBaremetal):
         # Get the command object to test
         self.cmd = baremetal_node.RebuildBaremetalNode(self.app, None)
 
+    def test_rebuild_baremetal_provision_state_active_and_configdrive(self):
+        arglist = ['node_uuid',
+                   '--config-drive', 'path/to/drive']
+        verifylist = [
+            ('node', 'node_uuid'),
+            ('provision_state', 'rebuild'),
+            ('config_drive', 'path/to/drive'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.baremetal_mock.node.set_provision_state.assert_called_once_with(
+            'node_uuid', 'rebuild',
+            cleansteps=None, configdrive='path/to/drive')
+
     def test_rebuild_no_wait(self):
         arglist = ['node_uuid']
         verifylist = [
@@ -1500,6 +1517,10 @@ class TestRebuildBaremetalProvisionState(TestBaremetal):
 
         self.cmd.take_action(parsed_args)
 
+        self.baremetal_mock.node.set_provision_state.assert_called_once_with(
+            'node_uuid', 'rebuild',
+            cleansteps=None, configdrive=None)
+
         self.baremetal_mock.node.wait_for_provision_state.assert_not_called()
 
     def test_rebuild_baremetal_provision_state_active_and_wait(self):
@@ -1948,6 +1969,7 @@ class TestBaremetalSet(TestBaremetal):
     @mock.patch.object(commonutils, 'get_from_stdin', autospec=True)
     @mock.patch.object(commonutils, 'handle_json_or_file_arg', autospec=True)
     def test_baremetal_set_target_raid_config(self, mock_handle, mock_stdin):
+        self.cmd.log = mock.Mock(autospec=True)
         target_raid_config_string = '{"raid": "config"}'
         expected_target_raid_config = {'raid': 'config'}
         mock_handle.return_value = expected_target_raid_config.copy()
@@ -1960,6 +1982,7 @@ class TestBaremetalSet(TestBaremetal):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
+        self.cmd.log.warning.assert_not_called()
         self.assertFalse(mock_stdin.called)
         mock_handle.assert_called_once_with(target_raid_config_string)
         self.baremetal_mock.node.set_target_raid_config.\
@@ -1970,6 +1993,7 @@ class TestBaremetalSet(TestBaremetal):
     @mock.patch.object(commonutils, 'handle_json_or_file_arg', autospec=True)
     def test_baremetal_set_target_raid_config_and_name(
             self, mock_handle, mock_stdin):
+        self.cmd.log = mock.Mock(autospec=True)
         target_raid_config_string = '{"raid": "config"}'
         expected_target_raid_config = {'raid': 'config'}
         mock_handle.return_value = expected_target_raid_config.copy()
@@ -1984,6 +2008,7 @@ class TestBaremetalSet(TestBaremetal):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
+        self.cmd.log.warning.assert_not_called()
         self.assertFalse(mock_stdin.called)
         mock_handle.assert_called_once_with(target_raid_config_string)
         self.baremetal_mock.node.set_target_raid_config.\
@@ -1996,6 +2021,7 @@ class TestBaremetalSet(TestBaremetal):
     @mock.patch.object(commonutils, 'handle_json_or_file_arg', autospec=True)
     def test_baremetal_set_target_raid_config_stdin(self, mock_handle,
                                                     mock_stdin):
+        self.cmd.log = mock.Mock(autospec=True)
         target_value = '-'
         target_raid_config_string = '{"raid": "config"}'
         expected_target_raid_config = {'raid': 'config'}
@@ -2010,6 +2036,7 @@ class TestBaremetalSet(TestBaremetal):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.cmd.take_action(parsed_args)
 
+        self.cmd.log.warning.assert_not_called()
         mock_stdin.assert_called_once_with('target_raid_config')
         mock_handle.assert_called_once_with(target_raid_config_string)
         self.baremetal_mock.node.set_target_raid_config.\
@@ -2020,6 +2047,7 @@ class TestBaremetalSet(TestBaremetal):
     @mock.patch.object(commonutils, 'handle_json_or_file_arg', autospec=True)
     def test_baremetal_set_target_raid_config_stdin_exception(
             self, mock_handle, mock_stdin):
+        self.cmd.log = mock.Mock(autospec=True)
         target_value = '-'
         mock_stdin.side_effect = exc.InvalidAttribute('bad')
 
@@ -2032,6 +2060,7 @@ class TestBaremetalSet(TestBaremetal):
         self.assertRaises(exc.InvalidAttribute,
                           self.cmd.take_action, parsed_args)
 
+        self.cmd.log.warning.assert_not_called()
         mock_stdin.assert_called_once_with('target_raid_config')
         self.assertFalse(mock_handle.called)
         self.assertFalse(
@@ -2367,6 +2396,7 @@ class TestBaremetalUnset(TestBaremetal):
         )
 
     def test_baremetal_unset_target_raid_config(self):
+        self.cmd.log = mock.Mock(autospec=True)
         arglist = [
             'node_uuid',
             '--target-raid-config',
@@ -2380,11 +2410,13 @@ class TestBaremetalUnset(TestBaremetal):
 
         self.cmd.take_action(parsed_args)
 
+        self.cmd.log.warning.assert_not_called()
         self.assertFalse(self.baremetal_mock.node.update.called)
         self.baremetal_mock.node.set_target_raid_config.\
             assert_called_once_with('node_uuid', {})
 
     def test_baremetal_unset_target_raid_config_and_name(self):
+        self.cmd.log = mock.Mock(autospec=True)
         arglist = [
             'node_uuid',
             '--name',
@@ -2400,6 +2432,7 @@ class TestBaremetalUnset(TestBaremetal):
 
         self.cmd.take_action(parsed_args)
 
+        self.cmd.log.warning.assert_not_called()
         self.baremetal_mock.node.set_target_raid_config.\
             assert_called_once_with('node_uuid', {})
         self.baremetal_mock.node.update.assert_called_once_with(
